---
title: Configuration reference
eleventyNavigation:
  key: Configuration reference
  parent: Reference guides
  order: 0
---
## Configuration file

Here is a full sample borgmatic configuration file including all available options: 

```yaml
{% include borgmatic/config.yaml %}
```

Note that you can also [download this configuration
file](https://torsion.org/borgmatic/docs/reference/config.yaml) for use locally.


## Related documentation

 * [Set up backups with borgmatic](https://torsion.org/borgmatic/docs/how-to/set-up-backups/)
 * [borgmatic command-line reference](https://torsion.org/borgmatic/docs/reference/command-line/)
